@@ -21,7 +21,7 @@ module Plugins.Date (Date(..)) where
 import Plugins
 
 import System.Locale
-import System.Time
+import Data.Time
 
 data Date = Date String String Int
     deriving (Read, Show)
@@ -32,6 +32,4 @@ instance Exec Date where
     rate  (Date _ _ r) = r
 
 date :: String -> IO String
-date format = do
-  t <- toCalendarTime =<< getClockTime
-  return $ formatCalendarTime defaultTimeLocale format t
+date format = getZonedTime >>= return . formatTime defaultTimeLocale format
